#
# spec file for package perl-Mojo-DOM58
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mojo-DOM58
Name:           perl-Mojo-DOM58
Version:        3.001
Release:        1.16
Summary:        Minimalistic HTML/XML DOM parser with CSS selectors
License:        Artistic-2.0
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DB/DBOOK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(JSON::PP)
BuildRequires:  perl(Test::More) >= 0.96
%{perl_requires}

%description
Mojo::DOM58 is a minimalistic and relaxed pure-perl HTML/XML DOM parser
based on Mojo::DOM. It supports the at https://html.spec.whatwg.org/ and at
https://www.w3.org/TR/xml/, and matching based on at
https://www.w3.org/TR/selectors/. It will even try to interpret broken HTML
and XML, so you should not use it for validation.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md examples prereqs.yml README
%license LICENSE

%changelog
* Thu Jun 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.001
  see /usr/share/doc/packages/perl-Mojo-DOM58/Changes
  3.001     2021-06-16 01:28:52 EDT
  - Update IRC metadata to libera.chat
* Tue Apr  6 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.000
  see /usr/share/doc/packages/perl-Mojo-DOM58/Changes
  3.000     2021-04-04 23:34:33 EDT
  - Added head and tail collection methods. (from Mojolicious 8.23)
  - Added EXPERIMENTAL support for :any-link pseudo-class. (from Mojolicious 8.42)
  - Added EXPERIMENTAL support for case-sensitive attribute selectors like
    [foo="bar" s]. (from Mojolicious 8.42)
  - Renamed experimental :matches pseudo-class to :is. (from Mojolicious 8.42)
  - Fixed a bug where the case-sensitivity identifier in attribute selectors was
    case-sensitive. (from Mojolicious 8.42)
  - Fixed a bug where select and ruby elements were parsed incorrectly.
    (from Mojolicious 8.54)
  - Added EXPERIMENTAL support for :scope and :has pseudo-classes.
    (from Mojolicious 8.54)
  - Added support for MOJO_DOM58_CSS_DEBUG environment variable to print
    diagnostics information for CSS selectors. (from Mojolicious 8.55)
  - Unknown CSS selectors will now throw exceptions. (from Mojolicious 8.66)
  - (INCOMPATIBLE CHANGE) Improved all_text method to exclude "<script>" and
    "<style>" from text extraction in HTML documents. (from Mojolicious 9.0)
* Tue Nov 19 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Add cpanspec.yml file
* Mon Nov 18 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Initial packaging
  * 2.000     2018-12-17 20:49:49 EST
  - Fixed warnings in collection uniq method when collection contains undefined
    values. (from Mojolicious 7.75)
  - Added support for namespace selectors like "ns|*". (from Mojolicious 7.77)
  - Added support for hyphen-separated list attribute selectors like
    "[hreflang|=en]". (from Mojolicious 7.77)
  - Added support for :link and :visited pseudo-classes. (from Mojolicious 7.77)
  - Improved performance of all DOM manipulation methods significantly when
    reusing Mojo::DOM58 objects. (from Mojolicious 7.78)
  - Added new_tag method. (from Mojolicious 7.78)
  - Added tag_to_html function. (from Mojolicious 7.78)
  - Added selector method. (from Mojolicious 7.79)
  - Improved HTML5.2 compliance. (from Mojolicious 8.02)
  * 1.005     2018-02-06 14:28:11 EST
  - Improved HTML Living Standard compliance (from Mojolicious 7.60)
  * 1.004     2017-11-11 16:46:13 EST
  - Added with_roles method to Mojo::DOM58 and collection objects to support
    applying roles with Role::Tiny. (from Mojolicious 7.43)
  * 1.003     2017-07-20 02:44:32 EDT
  - Added EXPERIMENTAL support for :matches pseudo-class and :not pseudo-class
    with compound selectors. (from Mojolicious 7.33)
  - Fixed a few form element value extraction bugs. (from Mojolicious 7.33)
  - Performance improvements (from Mojolicious 7.34)
  * 1.002     2017-04-01 16:11:40 EDT
  - Added html_attr_unescape function to Mojo::DOM58::Entities. (from
    Mojolicious 7.29)
  - Fixed unescaping of HTML5 attribute values. (from Mojolicious 7.29)
  * 1.001     2016-11-23 16:17:25 EST
  - Fix bug in Mojo::DOM58::Entities where the DATA handle would be mentioned
    in error messages. (from Mojolicious 7.03)
  * 1.000     2016-08-10 21:57:48 EDT
  - (INCOMPATIBLE CHANGE) Removed support for smart whitespace trimming from
    all_text and text methods, and fix whitespace bugs (from Mojolicious 7.0)
  - Fixed CSS selector for value-less attributes (from Mojolicious 7.0)
  * 0.999     2016-08-01 04:24:01 EDT (TRIAL RELEASE)
  - (INCOMPATIBLE CHANGE) Removed support for smart whitespace trimming from
    all_text and text methods, and fix whitespace bugs (from Mojolicious 7.0)
  - Fixed CSS selector for value-less attributes (from Mojolicious 7.0)
  * 0.002     2016-06-14 01:28:10 EDT
  - Added recognition of <slot> element (from Mojolicious 6.59)
  - Recognize legacy HTML entities without semicolons again (from Mojolicious 6.64)
  * 0.001     2016-03-27 16:12:42 EDT
  - First release
